@@ -335,30 +335,41 @@ def get_freq_damping(lam, suppress_warning=False):
     ----------
     lam : 1d ndarray; shape = (2n,)
         Vector of potentially complex eigenvalues. Pairs are assumed
-        to be adjacent
+        to be adjacent. Furthermore, each pair of values in `lam` is
+        assumed to be: :math:`-\omega_n (\zeta \pm \sqrt {\zeta^2 -
+        1})`. This is the case when `lam` are the eigenvalues of
+        :math:`A`, where :math:`A` is setup as shown in :func:`eigss`
+        (which has a :math:`-K` in it as opposed to a :math:`+K`).
     suppress_warning : bool; optional
         If True, do not print a warning if this routine finds that
         there are complex eigenvalues without an adjacent
         conjugate. Suppressing the warning can be useful for cases
         where the state-space matrix is complex. In that case, this
-        routine may not be that useful, but there's no sense in
-        printing a warning. See also the notes below.
+        routine may not be that useful, but there's no use in printing
+        a warning. See also the notes below.
 
     Returns
     -------
     wn : 1d ndarray; shape = (n,)
         Vector of natural frequencies (rad/sec) in the same order as
-        `lam`.
+        `lam`. `wn` is always greater than or equal to zero.
     zeta : 1d ndarray; shape = (n,)
         Vector of critical damping ratios:
 
-        =======  ====================================================
-        `zeta`   description
-        =======  ====================================================
-         < 1.0   underdamped; eigenvalues are complex conjugate pairs
-         = 1.0   critically damped; eigenvalues are real duplicates
-         > 1.0   overdamped; eigenvalues are real and unequal
-        =======  ====================================================
+        ========  ====================================================
+        \|zeta\|   description of eigenvalue pairs
+        ========  ====================================================
+         < 1.0    underdamped; eigenvalues are complex conjugate pairs
+         = 1.0    critically damped; eigenvalues are real duplicates
+         > 1.0    overdamped; eigenvalues are real and unequal
+        ========  ====================================================
+
+        .. note::
+            If `zeta` comes out negative, it could mean that the sign
+            on `lam` is the opposite of that expected. Or, you have
+            negative damping. If `zeta` should be positive for your
+            problem, just change the sign on `lam` (and see
+            description of the `lam` input).
 
     Notes
     -----
@@ -376,11 +387,11 @@ def get_freq_damping(lam, suppress_warning=False):
 
     .. math::
         \begin{aligned}
-           \lambda_1 &= \omega_n (\zeta + \sqrt {\zeta^2 - 1}) \\
-           \lambda_2 &= \omega_n (\zeta - \sqrt {\zeta^2 - 1})
+           \lambda_1 &= -\omega_n (\zeta + \sqrt {\zeta^2 - 1}) \\
+           \lambda_2 &= -\omega_n (\zeta - \sqrt {\zeta^2 - 1})
         \end{aligned}
 
-    The eigenvalue pairs will be real if :math:`\zeta >= 1.0` and
+    The eigenvalue pairs will be real if :math:`|\zeta| >= 1.0` and
     complex conjugates otherwise.
 
     The natural frequency :math:`\omega_n` is computed by taking the
@@ -406,7 +417,7 @@ def get_freq_damping(lam, suppress_warning=False):
 
     .. math::
         \begin{aligned}
-           \zeta &= \frac{\lambda_1 + \lambda_2}{2 \omega_n} \\
+           \zeta &= -\frac{\lambda_1 + \lambda_2}{2 \omega_n} \\
                  &= \frac{\omega_n (\zeta + \sqrt {\zeta^2 - 1})
                         + \omega_n (\zeta - \sqrt {\zeta^2 - 1})}
                         {2 \omega_n} \\
@@ -456,26 +467,26 @@ def get_freq_damping(lam, suppress_warning=False):
     True
     >>> np.allclose(zeta_extracted[i], zeta)
     True
+
+    Check sign convention. The first input follows the sign convention
+    described above, so should result in a positive 60% damping. The
+    second is the opposite, so should give -60% damping:
+
+    >>> ode.get_freq_damping([-3+4j, -3-4j])
+    (array([ 5.]), array([ 0.6]))
+    >>> ode.get_freq_damping([3+4j, 3-4j])
+    (array([ 5.]), array([-0.6]))
     """
     # find complex conjugate pairs:
     lam = np.atleast_1d(lam)
 
-    # Check for sign on lam ... if we assume lam is computed from A as
-    # defined in eigss (the convention used in pyYeti), then we really
-    # want to compute wn & zeta from -lam. We won't assume that
-    # though; instead, we'll just check the sign on the real part
-    # ... probably could just check one eigenvalue, but it's pretty
-    # cheap to do more of an average:
-    if lam.sum().real < 0:
-        lam = -lam
-
     lam1 = lam[::2]
     lam2 = lam[1::2]
     if lam1.shape[0] != lam2.shape[0]:
         raise ValueError("`lam` must be even length")
 
     mult = lam1 * lam2
-    add = lam1 + lam2
+    add = -(lam1 + lam2)
     if not suppress_warning:
         if (abs(mult.imag).max() > 1e-14) or (abs(add.imag).max() > 1e-14):
             warnings.warn(
@@ -487,8 +498,7 @@ def get_freq_damping(lam, suppress_warning=False):
             )
 
     wn = np.sqrt(abs(mult.real))
-    zeta = (lam1 + lam2).real / (2 * wn)
-
+    zeta = add.real / (2 * wn)
     return wn, zeta
 
 
@@ -881,7 +891,7 @@ def make_A(M, B, K):
     return A
 
 
-def solvepsd(fs, forcepsd, t_frc, freq, drmlist, incrb=2, rbduf=1.0, elduf=1.0):
+def solvepsd(fs, forcepsd, t_frc, freq, drmlist, rbduf=1.0, elduf=1.0, **kwargs):
     """
     Solve equations of motion in frequency domain with uncorrelated
     PSD forces.
@@ -937,22 +947,22 @@ def solvepsd(fs, forcepsd, t_frc, freq, drmlist, incrb=2, rbduf=1.0, elduf=1.0):
                [None, None, dtm, None],
                [ltma, ltmv, ltmd, ltmf]]
 
-    incrb : 0, 1, or 2; optional
-        An input to the :func:`fs.fsolve` method, it specifies how to
-        handle rigid-body responses:
-
-        ======  ===============================================
-        incrb   description
-        ======  ===============================================
-           0    no rigid-body is included
-           1    acceleration and velocity rigid-body only
-           2    all of rigid-body is included (see `fs.fsolve`)
-        ======  ===============================================
-
     rbduf : scalar; optional
         Rigid-body uncertainty factor
     elduf : scalar; optional
         Dynamic uncertainty factor
+    **kwargs : keyword arguments for ``fs.fsolve``; optional
+        Currently, there are two arguments available:
+
+        ============  ============================================
+          argument    brief description
+        ============  ============================================
+        incrb         specifies how to handle rigid-body responses
+        rf_disp_only  specifies how to handle residual-flexibility
+                      modes
+        ============  ============================================
+
+        See, for example, :func:`SolveUnc.fsolve`.
 
     Returns
     -------
@@ -969,10 +979,10 @@ def solvepsd(fs, forcepsd, t_frc, freq, drmlist, incrb=2, rbduf=1.0, elduf=1.0):
 
     Notes
     -----
-    This routine first calls `fs.fsolve` to solve the modal equations
-    of motion. Then, it scales the responses by the corresponding PSD
-    input force. All PSD responses are summed together for the overall
-    response. For example::
+    This routine first calls ``fs.fsolve`` to solve the modal
+    equations of motion. Then, it scales the responses by the
+    corresponding PSD input force. All PSD responses are summed
+    together for the overall response. For example::
 
         resp_psd = 0
         for i in range(forcepsd.shape[0]):
@@ -1049,7 +1059,7 @@ def solvepsd(fs, forcepsd, t_frc, freq, drmlist, incrb=2, rbduf=1.0, elduf=1.0):
     for i in range(rpsd):
         # solve for unit frequency response function for i'th force:
         genforce = t_frc[:, i : i + 1] @ unitforce
-        sol = fs.fsolve(genforce, freq, incrb)
+        sol = fs.fsolve(genforce, freq, **kwargs)
         if rbduf != 1.0:
             sol.a[fs.rb] *= rbduf
             sol.v[fs.rb] *= rbduf
